@@ -42,9 +42,10 @@ def _same_content(a: VirtualPath, b: VirtualPath) -> bool:
     # We could also replace this with a checksum check, then we could store them in a table and deduplicate
     # between multiple versions (not just against the lowest version). Decided against it because this is
     # are more faithful translation of the original code.
-    with a.open(byte_io=True, buffering=_BUF_SIZE) as afd, b.open(
-        byte_io=True, buffering=_BUF_SIZE
-    ) as bfd:
+    with (
+        a.open(byte_io=True, buffering=_BUF_SIZE) as afd,
+        b.open(byte_io=True, buffering=_BUF_SIZE) as bfd,
+    ):
         for a_chunk, b_chunk in itertools.zip_longest(afd, bfd, fillvalue=None):
             if a_chunk is None or b_chunk is None or a_chunk != b_chunk:
                 return False
