@@ -5,20 +5,12 @@ import stat
 import subprocess
 from typing import (
     AbstractSet,
-    List,
-    Mapping,
-    Iterable,
-    Tuple,
-    Optional,
-    Sequence,
-    Dict,
     Any,
-    Union,
-    Iterator,
     TypedDict,
     NotRequired,
-    Container,
+    Literal,
 )
+from collections.abc import Mapping, Iterable, Sequence, Iterator, Container
 
 from debputy.analysis import REFERENCE_DATA_TABLE
 from debputy.analysis.analysis_util import flatten_ppfs
@@ -63,25 +55,31 @@ PackagingFileInfo = TypedDict(
         "binary-package": NotRequired[str],
         "install-path": NotRequired[str],
         "install-pattern": NotRequired[str],
-        "file-categories": NotRequired[List[str]],
-        "config-features": NotRequired[List[str]],
+        "file-categories": NotRequired[list[str]],
+        "config-features": NotRequired[list[str]],
         "pkgfile-is-active-in-build": NotRequired[bool],
         "pkgfile-stem": NotRequired[str],
         "pkgfile-explicit-package-name": NotRequired[bool],
         "pkgfile-name-segment": NotRequired[str],
         "pkgfile-architecture-restriction": NotRequired[str],
         "likely-typo-of": NotRequired[str],
-        "likely-generated-from": NotRequired[List[str]],
-        "related-tools": NotRequired[List[str]],
-        "documentation-uris": NotRequired[List[str]],
-        "debputy-cmd-templates": NotRequired[List[List[str]]],
+        "likely-generated-from": NotRequired[list[str]],
+        "related-tools": NotRequired[list[str]],
+        "documentation-uris": NotRequired[list[str]],
+        "debputy-cmd-templates": NotRequired[list[str]],
         "generates": NotRequired[str],
         "generated-from": NotRequired[str],
     },
 )
+PackagingFileInfoStringListFieldKey = Literal[
+    "config-features",
+    "debputy-cmd-templates",
+    "documentation-uris",
+    "file-categories",
+]
 
 
-def _perl_json_bool(base: Optional[Any]) -> Optional[Any]:
+def _perl_json_bool(base: Any | None) -> Any | None:
     if base is None:
         return None
 
@@ -108,8 +106,8 @@ def scan_debian_dir(
     debian_dir: VirtualPath,
     *,
     uses_dh_sequencer: bool = True,
-    dh_sequences: Optional[AbstractSet[str]] = None,
-) -> Tuple[List[PackagingFileInfo], List[str], int, Optional[object]]:
+    dh_sequences: AbstractSet[str] | None = None,
+) -> tuple[list[PackagingFileInfo], list[str], int, object | None]:
     known_packaging_files = feature_set.known_packaging_files
     debputy_plugin_metadata = plugin_metadata_for_debputys_own_plugin()
     reference_data_set_names = [
@@ -119,8 +117,8 @@ def scan_debian_dir(
     for n in reference_data_set_names:
         assert n in REFERENCE_DATA_TABLE
 
-    annotated: List[PackagingFileInfo] = []
-    seen_paths: Dict[str, PackagingFileInfo] = {}
+    annotated: list[PackagingFileInfo] = []
+    seen_paths: dict[str, PackagingFileInfo] = {}
 
     if dh_sequences is None:
         r = read_dh_addon_sequences(debian_dir)
@@ -136,7 +134,7 @@ def scan_debian_dir(
     )
     is_debputy_package = debputy_integration_mode is not None
     dh_compat_level, dh_assistant_exit_code = extract_dh_compat_level()
-    dh_issues = []
+    dh_issues: object | None = []
 
     static_packaging_files = {
         kpf.detection_value: kpf
@@ -167,6 +165,7 @@ def scan_debian_dir(
     if dh_compat_level is not None:
         (
             all_dh_ppfs,
+            _,
             dh_issues,
             dh_assistant_exit_code,
         ) = resolve_debhelper_config_files(
@@ -197,7 +196,7 @@ def scan_debian_dir(
             "pkgfile-explicit-package-name": ppf.uses_explicit_package_name,
             "pkgfile-is-active-in-build": ppf.definition.has_active_command,
             "debputy-cmd-templates": [
-                ["debputy", "plugin", "show", "p-p-f", ppf.definition.stem]
+                f"debputy plugin show p-p-f {ppf.definition.stem}",
             ],
         }
         if ppf.fuzzy_match and key.endswith(".in"):
@@ -230,7 +229,7 @@ def scan_debian_dir(
 
         static_match = static_packaging_files.get(virtual_path.path)
         if static_match is not None:
-            details: PackagingFileInfo = {
+            details = {
                 "path": key,
             }
             annotated.append(details)
@@ -259,12 +258,12 @@ def _skip_path(virtual_path: VirtualPath) -> bool:
 def _fake_PPFClassSpec(
     debputy_plugin_metadata: DebputyPluginMetadata,
     stem: str,
-    doc_uris: Optional[Sequence[str]],
-    install_pattern: Optional[str],
+    doc_uris: Sequence[str] | None,
+    install_pattern: str | None,
     *,
-    default_priority: Optional[int] = None,
+    default_priority: int | None = None,
     packageless_is_fallback_for_all_packages: bool = False,
-    post_formatting_rewrite: Optional[str] = None,
+    post_formatting_rewrite: str | None = None,
     bug_950723: bool = False,
     has_active_command: bool = False,
 ) -> PackagerProvidedFileClassSpec:
@@ -295,7 +294,7 @@ def _fake_PPFClassSpec(
 
 
 def _relevant_dh_compat_rules(
-    compat_level: Optional[int],
+    compat_level: int | None,
     info: KnownPackagingFileInfo,
 ) -> Iterable[DHCompatibilityBasedRule]:
     if compat_level is None:
@@ -311,9 +310,9 @@ def _relevant_dh_compat_rules(
 
 
 def _kpf_install_pattern(
-    compat_level: Optional[int],
+    compat_level: int | None,
     ppkpf: PluginProvidedKnownPackagingFile,
-) -> Optional[str]:
+) -> str | None:
     for compat_rule in _relevant_dh_compat_rules(compat_level, ppkpf.info):
         install_pattern = compat_rule.get("install_pattern")
         if install_pattern is not None:
@@ -331,9 +330,9 @@ def resolve_debhelper_config_files(
     saw_dh: bool,
     ignore_paths: Container[str] = frozenset(),
     *,
-    debputy_integration_mode: Optional[DebputyIntegrationMode] = None,
-    cwd: Optional[str] = None,
-) -> Tuple[List[PackagerProvidedFile], Optional[object], int]:
+    debputy_integration_mode: DebputyIntegrationMode | None = None,
+    cwd: str | None = None,
+) -> tuple[list[PackagerProvidedFile], list[str], object | None, int]:
 
     dh_ppf_docs = {
         kpf.detection_value: kpf
@@ -353,10 +352,12 @@ def resolve_debhelper_config_files(
             cmd,
             stderr=subprocess.DEVNULL,
             cwd=cwd,
+            encoding="utf-8",
         )
     except (subprocess.CalledProcessError, FileNotFoundError) as e:
         config_files = []
         issues = None
+        missing_introspection: list[str] = []
         if isinstance(e, subprocess.CalledProcessError):
             exit_code = e.returncode
         else:
@@ -367,9 +368,8 @@ def resolve_debhelper_config_files(
             )
     else:
         result = json.loads(output)
-        config_files: List[Union[Mapping[str, Any], object]] = result.get(
-            "config-files", []
-        )
+        config_files = result.get("config-files", [])
+        missing_introspection = result.get("commands-not-introspectable", [])
         issues = result.get("issues")
         if _is_trace_log_enabled():
             _trace_log(
@@ -503,38 +503,35 @@ def resolve_debhelper_config_files(
             )
         )
     )
-    return all_dh_ppfs, issues, exit_code
+    return all_dh_ppfs, missing_introspection, issues, exit_code
 
 
 def _fake_plugin_feature_set(
     plugin_feature_set: PluginProvidedFeatureSet,
-    fake_defs: Mapping[str, PackagerProvidedFileClassSpec],
+    fake_defs: dict[str, PackagerProvidedFileClassSpec],
 ) -> PluginProvidedFeatureSet:
     return dataclasses.replace(plugin_feature_set, packager_provided_files=fake_defs)
 
 
 def _merge_list(
-    existing_table: Dict[str, Any],
-    key: str,
-    new_data: Optional[Sequence[str]],
+    existing_table: PackagingFileInfo,
+    key: PackagingFileInfoStringListFieldKey,
+    new_data: Sequence[str] | None,
 ) -> None:
     if not new_data:
         return
     existing_values = existing_table.get(key, [])
-    if isinstance(existing_values, tuple):
-        existing_values = list(existing_values)
-    assert isinstance(existing_values, list)
     seen = set(existing_values)
     existing_values.extend(x for x in new_data if x not in seen)
     existing_table[key] = existing_values
 
 
 def _merge_ppfs(
-    identified: List[PackagingFileInfo],
-    seen_paths: Dict[str, PackagingFileInfo],
-    ppfs: List[PackagerProvidedFile],
+    identified: list[PackagingFileInfo],
+    seen_paths: dict[str, PackagingFileInfo],
+    ppfs: list[PackagerProvidedFile],
     context: Mapping[str, PluginProvidedKnownPackagingFile],
-    dh_compat_level: Optional[int],
+    dh_compat_level: int | None,
 ) -> None:
     for ppf in ppfs:
         key = ppf.path.path
@@ -566,13 +563,14 @@ def _merge_ppfs(
         else:
             details = orig_details
             # We do not merge the "is typo" field; if the original
-            for k, v in [
-                ("pkgfile-stem", ppf.definition.stem),
-                ("pkgfile-explicit-package-name", ppf.definition.has_active_command),
-                ("binary-package", ppf.package_name),
-            ]:
-                if k not in details:
-                    details[k] = v
+            if "pkgfile-stem" not in details:
+                details["pkgfile-stem"] = ppf.definition.stem
+            if "pkgfile-explicit-package-name" not in details:
+                details["pkgfile-explicit-package-name"] = (
+                    ppf.definition.has_active_command
+                )
+            if "binary-package" not in details:
+                details["binary-package"] = ppf.package_name
             if ppf.definition.has_active_command and details.get(
                 "pkgfile-is-active-in-build", False
             ):
@@ -607,8 +605,8 @@ def _merge_ppfs(
 
 def _relevant_dh_commands(
     dh_rules_addons: Iterable[str],
-    cwd: Optional[str] = None,
-) -> Tuple[List[str], int]:
+    cwd: str | None = None,
+) -> tuple[list[str], int]:
     cmd = ["dh_assistant", "list-commands", "--output-format=json"]
     if dh_rules_addons:
         addons = ",".join(dh_rules_addons)
@@ -618,6 +616,7 @@ def _relevant_dh_commands(
             cmd,
             stderr=subprocess.DEVNULL,
             cwd=cwd,
+            encoding="utf-8",
         )
     except (FileNotFoundError, subprocess.CalledProcessError) as e:
         exit_code = 127
@@ -647,7 +646,7 @@ def _relevant_dh_commands(
 def _add_known_packaging_data(
     details: PackagingFileInfo,
     plugin_data: PluginProvidedKnownPackagingFile,
-    dh_compat_level: Optional[int],
+    dh_compat_level: int | None,
 ):
     install_pattern = _kpf_install_pattern(
         dh_compat_level,
@@ -677,15 +676,16 @@ def _add_known_packaging_data(
             _merge_list(details, "config-features", extra_config_features)
     if "install-pattern" not in details and install_pattern is not None:
         details["install-pattern"] = install_pattern
-    for mk, ok in [
-        ("file_categories", "file-categories"),
-        ("documentation_uris", "documentation-uris"),
-        ("debputy_cmd_templates", "debputy-cmd-templates"),
-    ]:
-        value = plugin_data.info.get(mk)
-        if value and ok == "debputy-cmd-templates":
-            value = [escape_shell(*c) for c in value]
-        _merge_list(details, ok, value)
+
+    _merge_list(details, "file-categories", plugin_data.info.get("file_categories"))
+    _merge_list(
+        details, "documentation-uris", plugin_data.info.get("documentation_uris")
+    )
+    _merge_list(
+        details,
+        "debputy-cmd-templates",
+        [escape_shell(*c) for c in plugin_data.info.get("debputy_cmd_templates", [])],
+    )
 
 
 def _scan_debian_dir(debian_dir: VirtualPath) -> Iterator[VirtualPath]:
