@@ -10,7 +10,7 @@ import sys
 import tempfile
 import textwrap
 from datetime import datetime
-from typing import Optional, List, Dict, Tuple
+from typing import Optional, List
 from collections.abc import Iterator
 
 from debputy.intermediate_manifest import (
