@@ -1318,7 +1318,13 @@ def compute_installed_size(fs_root: VirtualPath) -> int:
     for path in fs_root.all_paths():
         if path.is_symlink or path.is_file:
             try:
-                st = os.stat(path.fs_path)
+                # If it is a VirtualPathBase instance, the use its `.stat()` method
+                # since it might have the stat cached as a minor optimization on disk
+                # access. Other than that, the `os.lstat` fallback is sufficient.
+                if isinstance(path, VirtualPathBase):
+                    st = path.stat()
+                else:
+                    st = os.lstat(path.fs_path)
                 if st.st_nlink > 1:
                     hl_key = (st.st_dev, st.st_ino)
                     if hl_key in hard_links:
