@@ -14,8 +14,7 @@ from typing import (
 
 from debian.deb822 import Deb822
 
-from debputy import DEBPUTY_DOC_ROOT_DIR
-from debputy.architecture_support import dpkg_architecture_table
+from debputy.architecture_support import DpkgArchitectureBuildProcessValuesTable
 from debputy.deb_packaging_support import dpkg_field_list_pkg_dep
 from debputy.dh.debhelper_emulation import (
     dhe_filedoublearray,
@@ -56,6 +55,7 @@ from debputy.util import (
     assume_not_none,
     has_glob_magic,
 )
+from debputy.version import debputy_doc_root_dir
 
 
 class ContainsEverything:
@@ -130,7 +130,7 @@ DH_COMMANDS_REPLACED: Mapping[DebputyIntegrationMode, Container[str]] = {
     INTEGRATION_MODE_FULL: ContainsEverything(),
 }
 
-_GS_DOC = f"{DEBPUTY_DOC_ROOT_DIR}/GETTING-STARTED-WITH-dh-debputy.md"
+_GS_DOC = f"{debputy_doc_root_dir()}/GETTING-STARTED-WITH-dh-debputy.md"
 MIGRATION_AID_FOR_OVERRIDDEN_COMMANDS = {
     "dh_installinit": f"{_GS_DOC}#covert-your-overrides-for-dh_installsystemd-dh_installinit-if-any",
     "dh_installsystemd": f"{_GS_DOC}#covert-your-overrides-for-dh_installsystemd-dh_installinit-if-any",
@@ -298,7 +298,7 @@ def _dh_config_file(
     if remove_on_migration:
         feature_migration.remove_on_success(dh_config_file.fs_path)
     substitution = DHMigrationSubstitution(
-        dpkg_architecture_table(),
+        DpkgArchitectureBuildProcessValuesTable(),
         acceptable_migration_issues,
         feature_migration,
         mutable_manifest,
@@ -585,7 +585,7 @@ def migrate_dh_builtusing(
             feature_migration.warn(
                 f"Migrate all `${{dh-builtusing:custom-pattern}}` instances in the"
                 f" (Static-)Built-Using of {pkg.name} to"
-                f" `packages.{pkg.name}.(static-)built-using.sources: glob-pattern`"
+                f" `packages.{pkg.name}.(static-)built-using.sources-for: glob-pattern`"
                 f" in `debian/debputy.manifest`"
             )
 
@@ -633,7 +633,7 @@ def migrate_clean_file(
     mutable_manifest = assume_not_none(migration_request.manifest.mutable_manifest)
 
     substitution = DHMigrationSubstitution(
-        dpkg_architecture_table(),
+        DpkgArchitectureBuildProcessValuesTable(),
         migration_request.acceptable_migration_issues,
         feature_migration,
         mutable_manifest,
