@@ -1,10 +1,16 @@
-from typing import cast, TYPE_CHECKING
+"""Exceptions with basic type annotations for accessors and constructors."""
+
+from typing import Any, cast, TYPE_CHECKING
 
 if TYPE_CHECKING:
     from debputy.plugin.api.impl_types import DebputyPluginMetadata
 
 
 class DebputyRuntimeError(RuntimeError):
+
+    def __init__(self, message: str, *args: Any) -> None:
+        super().__init__(message, *args)
+
     @property
     def message(self) -> str:
         return cast("str", self.args[0])
@@ -33,18 +39,30 @@ class DebputyDpkgGensymbolsError(DebputyRuntimeError):
 
 
 class SymlinkLoopError(ValueError):
+
+    def __init__(self, message: str, *args: Any) -> None:
+        super().__init__(message, *args)
+
     @property
     def message(self) -> str:
         return cast("str", self.args[0])
 
 
 class PureVirtualPathError(TypeError):
+
+    def __init__(self, message: str, *args: Any) -> None:
+        super().__init__(message, *args)
+
     @property
     def message(self) -> str:
         return cast("str", self.args[0])
 
 
 class TestPathWithNonExistentFSPathError(TypeError):
+
+    def __init__(self, message: str, *args: Any) -> None:
+        super().__init__(message, *args)
+
     @property
     def message(self) -> str:
         return cast("str", self.args[0])
@@ -83,6 +101,16 @@ class PluginMetadataError(PluginBaseError):
 
 
 class PluginConflictError(PluginBaseError):
+
+    def __init__(
+        self,
+        message: str,
+        plugin_a: "DebputyPluginMetadata",
+        plugin_b: "DebputyPluginMetadata",
+        *args: Any,
+    ) -> None:
+        super().__init__(message, plugin_a, plugin_b, *args)
+
     @property
     def plugin_a(self) -> "DebputyPluginMetadata":
         return cast("DebputyPluginMetadata", self.args[1])
