@@ -1356,13 +1356,21 @@ class VirtualPathWithReference(VirtualFSPathBase, ABC):
         buffering: int = -1,
     ) -> TextIO: ...
 
+    @overload
+    def open(
+        self,
+        *,
+        byte_io: Literal[True],
+        buffering: Literal[0] = ...,
+    ) -> io.FileIO: ...
+
     @overload
     def open(
         self,
         *,
         byte_io: Literal[True],
         buffering: int = -1,
-    ) -> BinaryIO: ...
+    ) -> io.BufferedReader: ...
 
     def open(self, *, byte_io=False, buffering=-1):
         reference_path = self._reference_path
@@ -1713,13 +1721,21 @@ class VirtualTestPath(FSPath):
         buffering: int = -1,
     ) -> TextIO: ...
 
+    @overload
+    def open(
+        self,
+        *,
+        byte_io: Literal[True],
+        buffering: Literal[0] = ...,
+    ) -> io.FileIO: ...
+
     @overload
     def open(
         self,
         *,
         byte_io: Literal[True],
         buffering: int = -1,
-    ) -> BinaryIO: ...
+    ) -> io.BufferedReader: ...
 
     def open(self, *, byte_io=False, buffering=-1):
         if self._content is None:
@@ -1824,13 +1840,21 @@ class OSFSOverlayBase(VirtualPathBase, Generic[FSP]):
         buffering: int = -1,
     ) -> TextIO: ...
 
+    @overload
+    def open(
+        self,
+        *,
+        byte_io: Literal[True],
+        buffering: Literal[0] = ...,
+    ) -> io.FileIO: ...
+
     @overload
     def open(
         self,
         *,
         byte_io: Literal[True],
         buffering: int = -1,
-    ) -> BinaryIO: ...
+    ) -> io.BufferedReader: ...
 
     def open(self, *, byte_io=False, buffering=-1):
         # Allow symlinks for open here, because we can let the OS resolve the symlink reliably in this
@@ -2161,7 +2185,7 @@ class OSFSControlPath(OSFSOverlayBase["FSControlPath"]):
         use_fs_path_mode: bool = False,
         mode: int = 0o0644,
         mtime: float | None = None,
-    ) -> ContextManager["VirtualPath"]:
+    ) -> Iterator["VirtualPath"]:
         if "/" in name or name in {".", ".."}:
             raise ValueError(f'Invalid file name: "{name}"')
         if not self.is_dir:
@@ -2198,7 +2222,7 @@ class OSFSControlPath(OSFSOverlayBase["FSControlPath"]):
         self,
         *,
         use_fs_path_mode: bool = False,
-    ) -> ContextManager[str]:
+    ) -> Iterator[str]:
         if not self.is_file:
             raise TypeError(
                 f'Cannot replace contents of "{self._orphan_safe_path()}" as it is not a file'
