@@ -1685,9 +1685,7 @@ class HighLevelManifest:
 @dataclasses.dataclass(slots=True)
 class SearchDirOrderState:
     search_dir: VirtualPath
-    applies_to: set[BinaryPackage] | frozenset[BinaryPackage] = dataclasses.field(
-        default_factory=set
-    )
+    applies_to: set[BinaryPackage] = dataclasses.field(default_factory=set)
     after: set[str] = dataclasses.field(default_factory=set)
 
 
@@ -1723,7 +1721,7 @@ def _determine_search_dir_order(
     default_search_dirs: list[VirtualPath],
     source_root: VirtualPath,
 ) -> Sequence[SearchDir]:
-    search_dir_table = {}
+    search_dir_table = dict[str, SearchDirOrderState]()
     assert requested.keys() <= all_pkgs
     for pkg in all_pkgs:
         paths = requested.get(pkg, default_search_dirs)
@@ -1740,7 +1738,7 @@ def _determine_search_dir_order(
             previous_search_dir = search_dir_state
 
     search_dirs_in_order = []
-    released = set()
+    released = set[str]()
     remaining = set()
     for search_dir_state in search_dir_table.values():
         if not (search_dir_state.after <= released):
@@ -1771,7 +1769,7 @@ def _determine_search_dir_order(
     search_dirs_in_order.append(
         SearchDirOrderState(
             source_root,
-            all_pkgs,
+            set(all_pkgs),
         )
     )
 
