@@ -1,4 +1,4 @@
-import collections
+import collections.abc
 import contextlib
 from collections.abc import Callable, Mapping, Iterator
 from typing import (
@@ -10,6 +10,7 @@ from typing import (
 
 from debian.debian_support import DpkgArchTable
 
+import debputy.util
 from debputy.highlevel_manifest import (
     HighLevelManifest,
     PackageTransformationDefinition,
@@ -71,45 +72,28 @@ from .plugin.plugin_state import with_binary_pkg_parsing_context, begin_parsing_
 from .yaml import YAMLError, MANIFEST_YAML
 
 
-if TYPE_CHECKING:
-    from .plugins.debputy.binary_package_rules import BinaryVersion
-
-
-try:
-    from Levenshtein import distance
-except ImportError:
-
-    def _detect_possible_typo(
-        _d,
-        _key,
-        _attribute_parent_path: AttributePath,
-        required: bool,
-    ) -> None:
-        if required:
-            _info(
-                "Install python3-levenshtein to have debputy try to detect typos in the manifest."
-            )
-
-else:
-
-    def _detect_possible_typo(
-        d,
-        key,
-        _attribute_parent_path: AttributePath,
-        _required: bool,
-    ) -> None:
+def _detect_possible_typo(
+    d: collections.abc.Iterable[str],
+    key: str,
+    attribute_parent_path: AttributePath,
+    required: bool,
+) -> None:
+    if debputy.util.CAN_DETECT_TYPOS:
         k_len = len(key)
         for actual_key in d:
             if abs(k_len - len(actual_key)) > 2:
                 continue
-            d = distance(key, actual_key)
-            if d > 2:
+            if debputy.util.distance(key, actual_key) > 2:
                 continue
-            path = _attribute_parent_path.path
+            path = attribute_parent_path.path
             ref = f'at "{path}"' if path else "at the manifest root level"
             _warn(
                 f'Possible typo: The key "{actual_key}" should probably have been "{key}" {ref}'
             )
+    elif required:
+        _info(
+            "Install python3-levenshtein to have debputy try to detect typos in the manifest."
+        )
 
 
 def _per_package_subst_variables(
@@ -151,8 +135,8 @@ class HighLevelManifestParser(ParserContextData):
         self._package_state_stack: list[PackageTransformationDefinition] = []
         self._plugin_provided_feature_set = plugin_provided_feature_set
         self._debputy_integration_mode = debputy_integration_mode
-        self._declared_variables = {}
-        self._used_named_envs = set()
+        self._declared_variables = dict[str, AttributePath]()
+        self._used_named_envs = set[str]()
         self._build_environments: BuildEnvironments | None = BuildEnvironments(
             {},
             None,
@@ -171,7 +155,9 @@ class HighLevelManifestParser(ParserContextData):
         self._debian_dir = debian_dir
 
         # Delayed initialized; we rely on this delay to parse the variables.
-        self._all_package_states = None
+        self._all_package_states: dict[str, PackageTransformationDefinition] | None = (
+            None
+        )
 
         self._install_rules: list[InstallRule] | None = None
         self._remove_during_clean_rules: list[FileSystemMatchRule] = []
@@ -183,7 +169,6 @@ class HighLevelManifestParser(ParserContextData):
             return
         substitution = self._substitution
         binary_packages = self._binary_packages
-        assert self._all_package_states is None
 
         self._all_package_states = {
             n: PackageTransformationDefinition(
@@ -432,9 +417,8 @@ class HighLevelManifestParser(ParserContextData):
                 f'The environment "{name}" requested at {attribute_path.path} was not'
                 f" defined in the `build-environments`"
             )
-        else:
-            self._used_named_envs.add(name)
-            return env
+        self._used_named_envs.add(name)
+        return env
 
     def build_environments(self) -> BuildEnvironments:
         v = self._build_environments
