@@ -1161,7 +1161,7 @@ class DiscardRule(InstallRule):
         limit_to = self._limit_to
         if limit_to:
             matches = {x.match_rule.path for x in limit_to}
-            search_dirs = tuple(
+            search_dirs: Sequence[SearchDir] = tuple(
                 s
                 for s in install_context.search_dirs
                 if s.search_dir.fs_path in matches
