@@ -79,7 +79,7 @@ class AptCache:
             self._state = "failed"
             self._load_error = f"apt-get exited with {e.returncode}"
             return
-        packages = {}
+        packages = dict[str, PackageInformation]()
         for raw_file_line in files_raw.split("\n"):
             if not raw_file_line or raw_file_line.isspace():
                 continue
@@ -132,6 +132,8 @@ def parse_apt_file(filename: str) -> Iterable[PackageInformation]:
         stdin=subprocess.DEVNULL,
         stdout=subprocess.PIPE,
     )
+    # Tell mypy that stdout=PIPE implies stdout in the result.
+    assert proc.stdout is not None
     with proc:
         for stanza in Deb822.iter_paragraphs(proc.stdout):
             pkg_info = stanza_to_package_info(stanza)
