@@ -10,17 +10,15 @@ from typing import (
     Optional,
     List,
     Union,
-    Callable,
-    Mapping,
     Self,
     Dict,
-    Iterable,
     Any,
     Tuple,
 )
+from collections.abc import Callable, Mapping, Iterable
 
 import debputy.lsp.data as data_dir
-from debputy.lsp.lsp_reference_keyword import ALL_PUBLIC_NAMED_STYLES
+from debputy.lsp.named_styles import ALL_PUBLIC_NAMED_STYLES
 from debputy.lsp.vendoring._deb822_repro.types import FormatterCallback
 from debputy.lsp.vendoring.wrap_and_sort import wrap_and_sort_formatter
 from debputy.packages import SourcePackage
@@ -63,10 +61,10 @@ _WAS_DEFAULTS = {
 
 @dataclasses.dataclass(slots=True, frozen=True, kw_only=True)
 class PreferenceOption(Generic[PT]):
-    key: Union[str, List[str]]
-    expected_type: Union[Type[PT], Callable[[Any], Optional[str]]]
+    key: str | list[str]
+    expected_type: type[PT] | Callable[[Any], str | None]
     description: str
-    default_value: Optional[Union[PT, Callable[[CommentedMap], Optional[PT]]]] = None
+    default_value: PT | Callable[[CommentedMap], PT | None] | None = None
 
     @property
     def name(self) -> str:
@@ -83,14 +81,14 @@ class PreferenceOption(Generic[PT]):
         filename: str,
         key: str,
         data: CommentedMap,
-    ) -> Optional[PT]:
+    ) -> PT | None:
         v = data.mlget(self.key, list_ok=True)
         if v is None:
             default_value = self.default_value
             if callable(default_value):
                 return default_value(data)
             return default_value
-        val_issue: Optional[str] = None
+        val_issue: str | None = None
         expected_type = self.expected_type
         if not isinstance(expected_type, type) and callable(self.expected_type):
             val_issue = self.expected_type(v)
@@ -112,11 +110,11 @@ def _is_packaging_team_default(m: CommentedMap) -> bool:
     return v.endswith((" maintainer", " maintainers", " team"))
 
 
-def _false_when_formatting_content(m: CommentedMap) -> Optional[bool]:
+def _false_when_formatting_content(m: CommentedMap) -> bool | None:
     return m.mlget(_NORMALISE_FIELD_CONTENT_KEY, list_ok=True, default=False) is True
 
 
-MAINT_OPTIONS: List[PreferenceOption] = [
+MAINT_OPTIONS: list[PreferenceOption] = [
     PreferenceOption(
         key="canonical-name",
         expected_type=str,
@@ -420,7 +418,7 @@ FORMATTING_OPTIONS = [
         default_value=False,
         description=textwrap.dedent(
             """\
-    Whether to canonical field names of known `deb822` fields.
+    Whether to canonicalize field names of known `deb822` fields.
 
     This causes formatting to align known fields in `deb822` files with their
     canonical spelling. As an examples:
@@ -455,8 +453,8 @@ FORMATTING_OPTIONS = [
 
 @dataclasses.dataclass(slots=True, frozen=True)
 class EffectiveFormattingPreference:
-    deb822_short_indent: Optional[bool] = None
-    deb822_always_wrap: Optional[bool] = None
+    deb822_short_indent: bool | None = None
+    deb822_always_wrap: bool | None = None
     deb822_trailing_separator: bool = False
     deb822_normalize_field_content: bool = False
     deb822_normalize_field_order: bool = False
@@ -514,9 +512,9 @@ class EffectiveFormattingPreference:
 
 @dataclasses.dataclass(slots=True, frozen=True)
 class MaintainerPreference:
-    canonical_name: Optional[str] = None
+    canonical_name: str | None = None
     is_packaging_team: bool = False
-    formatting: Optional[EffectiveFormattingPreference] = None
+    formatting: EffectiveFormattingPreference | None = None
 
     @classmethod
     def from_file(
@@ -547,8 +545,8 @@ class MaintainerPreferenceTable:
 
     @classmethod
     def load_preferences(cls) -> Self:
-        named_styles: Dict[str, EffectiveFormattingPreference] = {}
-        maintainer_preferences: Dict[str, MaintainerPreference] = {}
+        named_styles: dict[str, EffectiveFormattingPreference] = {}
+        maintainer_preferences: dict[str, MaintainerPreference] = {}
 
         path = importlib.resources.files(data_dir).joinpath(BUILTIN_STYLES)
 
@@ -577,8 +575,8 @@ class MaintainerPreferenceTable:
 
 
 def parse_file(
-    named_styles: Dict[str, EffectiveFormattingPreference],
-    maintainer_preferences: Dict[str, MaintainerPreference],
+    named_styles: dict[str, EffectiveFormattingPreference],
+    maintainer_preferences: dict[str, MaintainerPreference],
     filename: str,
     fd,
 ) -> None:
@@ -652,7 +650,7 @@ def extract_maint_email(maint: str) -> str:
     return maint[idx + 1 : -1]
 
 
-def _parse_salsa_ci_boolean(value: Union[str, int, bool]) -> bool:
+def _parse_salsa_ci_boolean(value: str | int | bool) -> bool:
     if isinstance(value, str):
         return value in ("yes", "1", "true")
     elif not isinstance(value, (int, bool)):
@@ -661,7 +659,7 @@ def _parse_salsa_ci_boolean(value: Union[str, int, bool]) -> bool:
         return value is True or value == 1
 
 
-def _read_salsa_ci_wrap_and_sort_enabled(salsa_ci: Optional[CommentedMap]) -> bool:
+def _read_salsa_ci_wrap_and_sort_enabled(salsa_ci: CommentedMap | None) -> bool:
     sentinel = object()
     disable_wrap_and_sort_raw = salsa_ci.mlget(
         ["variables", "SALSA_CI_DISABLE_WRAP_AND_SORT"],
@@ -690,9 +688,9 @@ def _read_salsa_ci_wrap_and_sort_enabled(salsa_ci: Optional[CommentedMap]) -> bo
 
 def determine_effective_preference(
     maint_preference_table: MaintainerPreferenceTable,
-    source_package: Optional[SourcePackage],
-    salsa_ci: Optional[CommentedMap],
-) -> Tuple[Optional[EffectiveFormattingPreference], Optional[str], Optional[str]]:
+    source_package: SourcePackage | None,
+    salsa_ci: CommentedMap | None,
+) -> tuple[EffectiveFormattingPreference | None, str | None, str | None]:
     style = source_package.fields.get("X-Style") if source_package is not None else None
     if style is not None:
         if style not in ALL_PUBLIC_NAMED_STYLES:
@@ -744,7 +742,7 @@ def determine_effective_preference(
         detected_style = maint_pref.formatting if maint_pref is not None else None
         tool_w_args = _guess_tool_from_style(maint_preference_table, detected_style)
         return detected_style, tool_w_args, None
-    all_styles: List[Optional[EffectiveFormattingPreference]] = []
+    all_styles: list[EffectiveFormattingPreference | None] = []
     if maint_pref is not None:
         all_styles.append(maint_pref.formatting)
     for uploader in _UPLOADER_SPLIT_RE.split(uploaders):
@@ -764,8 +762,8 @@ def determine_effective_preference(
 
 def _guess_tool_from_style(
     maint_preference_table: MaintainerPreferenceTable,
-    pref: Optional[EffectiveFormattingPreference],
-) -> Optional[str]:
+    pref: EffectiveFormattingPreference | None,
+) -> str | None:
     if pref is None:
         return None
     if maint_preference_table.named_styles["black"] == pref:
@@ -788,7 +786,7 @@ def _split_options(args: Iterable[str]) -> Iterable[str]:
 @functools.lru_cache
 def parse_salsa_ci_wrap_and_sort_args(
     args: str,
-) -> Optional[EffectiveFormattingPreference]:
+) -> EffectiveFormattingPreference | None:
     options = dict(_WAS_DEFAULTS)
     for arg in _split_options(args.split()):
         v = _WAS_OPTIONS.get(arg)
