@@ -81,7 +81,7 @@ _LOOKS_LIKE_EMAIL = re.compile(
 """,
     re.VERBOSE,
 )
-_NO_CORRECTIONS = tuple()
+_NO_CORRECTIONS = tuple[str]()
 _WORDLISTS = [
     "debian-wordlist.dic",
 ]
