@@ -4,18 +4,19 @@ import logging
 import sys
 import textwrap
 from abc import ABC
+from collections.abc import Iterable, Callable, Iterator
+from typing import (
+    Optional,
+    Union,
+    TYPE_CHECKING,
+    Type,
+    cast,
+    List,
+    Generic,
+)
 
 try:
-    from typing import (
-        Optional,
-        Union,
-        TYPE_CHECKING,
-        Type,
-        cast,
-        List,
-        Generic,
-    )
-    from collections.abc import Iterable, Callable, Iterator
+
     from debian._util import T
     from .types import TE, R, TokenOrElement
 
@@ -23,9 +24,7 @@ try:
         [Iterable[Union[TokenOrElement, TE]]], Iterable[Union[TokenOrElement, R]]
     ]
 except ImportError:
-    # pylint: disable=unnecessary-lambda-assignment
-    TYPE_CHECKING = False
-    cast = lambda t, v: v
+    pass
 
 
 if TYPE_CHECKING:
