@@ -1,8 +1,12 @@
 import re
 import sys
 import weakref
+from collections.abc import Iterable, Callable
+from typing import Optional, cast, TYPE_CHECKING, Union, Dict
 from weakref import ReferenceType
 
+from debian._util import resolve_ref, _strI
+
 from ._util import BufferingIterator
 from .locatable import (
     Locatable,
@@ -12,15 +16,6 @@ from .locatable import (
     ONE_LINE_RANGE,
     Position,
 )
-from debian._util import resolve_ref, _strI
-
-try:
-    from typing import Optional, cast, TYPE_CHECKING, Union, Dict
-    from collections.abc import Iterable, Callable
-except ImportError:
-    # pylint: disable=unnecessary-lambda-assignment
-    TYPE_CHECKING = False
-    cast = lambda t, v: v
 
 if TYPE_CHECKING:
     from .parsing import Deb822Element
