@@ -79,30 +79,25 @@ if TYPE_CHECKING:
 
 try:
     from Levenshtein import distance
+
+    _WARN_ONCE: bool | None = None
 except ImportError:
     _WARN_ONCE = False
 
-    def _detect_possible_typo(
-        _key: str,
-        _value: object,
-        _manifest_attributes: Mapping[str, "AttributeDescription"],
-        _path: "AttributePath",
-    ) -> None:
-        global _WARN_ONCE
-        if not _WARN_ONCE:
-            _WARN_ONCE = True
-            _info(
-                "Install python3-levenshtein to have debputy try to detect typos in the manifest."
-            )
 
-else:
-
-    def _detect_possible_typo(
-        key: str,
-        value: object,
-        manifest_attributes: Mapping[str, "AttributeDescription"],
-        path: "AttributePath",
-    ) -> None:
+def _detect_possible_typo(
+    key: str,
+    value: object,
+    manifest_attributes: Mapping[str, "AttributeDescription"],
+    path: "AttributePath",
+) -> None:
+    global _WARN_ONCE
+    if _WARN_ONCE == False:
+        _WARN_ONCE = True
+        _info(
+            "Install python3-levenshtein to have debputy try to detect typos in the manifest."
+        )
+    elif _WARN_ONCE is None:
         k_len = len(key)
         key_path = path[key]
         matches: list[str] = []
@@ -209,6 +204,9 @@ class AttributeTypeHandler:
     ) -> "AttributeTypeHandler":
         if mapper is None:
             return self
+        _combined_mapper: Callable[
+            [Any, AttributePath, Optional["ParserContextData"]], Any
+        ]
         if self.mapper is not None:
             m = self.mapper
 
@@ -498,14 +496,15 @@ def _is_path_attribute_candidate(
     return isinstance(match_type, type) and issubclass(match_type, FileSystemMatchRule)
 
 
-if typing.is_typeddict(DebputyParsedContent):
-    is_typeddict = typing.is_typeddict
-else:
-
-    def is_typeddict(t: Any) -> bool:
-        if typing.is_typeddict(t):
-            return True
-        return isinstance(t, type) and issubclass(t, DebputyParsedContent)
+def is_typeddict(t: Any) -> bool:
+    return typing.is_typeddict(t) or (
+        # Logically, not is_typeddict(t) and is subclass(DebputyParsedContent)
+        # implies not is_typeddict(DebputyParsedContent)
+        # except that subclass *fails* for typeddicts.
+        not typing.is_typeddict(DebputyParsedContent)
+        and isinstance(t, type)
+        and issubclass(t, DebputyParsedContent)
+    )
 
 
 class ParserGenerator:
