@@ -31,7 +31,6 @@ from typing import (
 )
 
 import debputy
-from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy.exceptions import (
     DebputySubstitutionError,
     PluginConflictError,
@@ -51,7 +50,6 @@ from debputy.manifest_parser.exceptions import ManifestParseException
 from debputy.manifest_parser.parser_data import ParserContextData
 from debputy.manifest_parser.tagging_types import TypeMapping
 from debputy.manifest_parser.util import AttributePath
-from debputy.manifest_parser.util import resolve_package_type_selectors
 from debputy.plugin.api.doc_parsing import (
     DEBPUTY_DOC_REFERENCE_DATA_PARSER,
     parser_type_name,
@@ -99,7 +97,6 @@ from debputy.plugin.api.spec import (
     MetadataAutoDetector,
     PluginInitializationEntryPoint,
     DebputyPluginInitializer,
-    PackageTypeSelector,
     FlushableSubstvars,
     ParserDocumentation,
     PackageProcessor,
@@ -145,7 +142,9 @@ from debputy.util import (
     print_command,
     _warn,
     _debug_log,
+    PackageTypeSelector,
 )
+from debputy.version import debputy_doc_root_dir
 from debputy.yaml import MANIFEST_YAML
 
 if TYPE_CHECKING:
@@ -248,7 +247,9 @@ class DebputyPluginInitializerProvider(DebputyPluginInitializer):
         metadata = self._plugin_metadata
         if metadata.plugin_name in self._feature_set.plugin_data:
             raise PluginConflictError(
-                f'The plugin "{metadata.plugin_name}" has already been loaded!?'
+                f'The plugin "{metadata.plugin_name}" has already been loaded!?',
+                metadata,
+                metadata,
             )
         assert (
             metadata.api_compat_version == 1
@@ -270,7 +271,7 @@ class DebputyPluginInitializerProvider(DebputyPluginInitializer):
                     f" callable (callable returns False). The specified entry point identifies"
                     f' itself as "{initializer.__qualname__}".'
                 ) from e
-            elif isinstance(e, PluginBaseError):
+            if isinstance(e, PluginBaseError):
                 raise
             raise PluginInitializationError(
                 f"Exception while attempting to load plugin {metadata.plugin_name}"
@@ -446,7 +447,7 @@ class DebputyPluginInitializerProvider(DebputyPluginInitializer):
         auto_detector_id: str,
         auto_detector: MetadataAutoDetector,
         *,
-        package_type: PackageTypeSelector = "deb",
+        package_types: PackageTypeSelector = PackageTypeSelector.DEB,
     ) -> None:
         if auto_detector_id in self._plugin_detector_ids:
             raise ValueError(
@@ -457,7 +458,6 @@ class DebputyPluginInitializerProvider(DebputyPluginInitializer):
         all_detectors = self._feature_set.metadata_maintscript_detectors
         if self._plugin_name not in all_detectors:
             all_detectors[self._plugin_name] = []
-        package_types = resolve_package_type_selectors(package_type)
         all_detectors[self._plugin_name].append(
             MetadataOrMaintscriptDetector(
                 detector_id=auto_detector_id,
@@ -625,7 +625,7 @@ class DebputyPluginInitializerProvider(DebputyPluginInitializer):
         processor: PackageProcessor,
         *,
         depends_on_processor: Iterable[str] = tuple(),
-        package_type: PackageTypeSelector = "deb",
+        package_types: PackageTypeSelector = PackageTypeSelector.DEB,
     ) -> None:
         self._restricted_api(allowed_plugins={"lua", "debputy-self-hosting"})
         package_processors = self._feature_set.all_package_processors
@@ -673,7 +673,7 @@ class DebputyPluginInitializerProvider(DebputyPluginInitializer):
 
         package_processors[processor_key] = PluginProvidedPackageProcessor(
             processor_id,
-            resolve_package_type_selectors(package_type),
+            package_types,
             wrap_plugin_code(self._plugin_name, processor),
             frozenset(dependencies),
             self._plugin_metadata,
@@ -1750,12 +1750,11 @@ def load_plugin_features(
                     " module might have tainted the feature set."
                 )
                 raise e from None
-            else:
-                _warn(
-                    f"The optional plugin {plugin_metadata.plugin_name} failed during load. The plugin was"
-                    f" deactivated. Use debug mode (--debug/DEBPUTY_DEBUG=1) to show the stacktrace"
-                    f" (the warning will become an error)"
-                )
+            _warn(
+                f"The optional plugin {plugin_metadata.plugin_name} failed during load. The plugin was"
+                f" deactivated. Use debug mode (--debug/DEBPUTY_DEBUG=1) to show the stacktrace"
+                f" (the warning will become an error)"
+            )
 
     return plugin_feature_set
 
@@ -2080,7 +2079,7 @@ def _json_plugin_loader(
                 if docs is not None and isinstance(docs, list):
                     docs = [
                         (
-                            d.replace("@DEBPUTY_DOC_ROOT_DIR@", DEBPUTY_DOC_ROOT_DIR)
+                            d.replace("@DEBPUTY_DOC_ROOT_DIR@", debputy_doc_root_dir())
                             if isinstance(d, str)
                             else d
                         )
