@@ -1,5 +1,6 @@
 import contextlib
 import dataclasses
+import io
 import os
 import tempfile
 import textwrap
@@ -11,7 +12,6 @@ from typing import (
     Any,
     TYPE_CHECKING,
     TextIO,
-    BinaryIO,
     Generic,
     ContextManager,
     get_args,
@@ -1392,13 +1392,21 @@ class VirtualPath:
         buffering: int = -1,
     ) -> TextIO: ...
 
+    @overload
+    def open(
+        self,
+        *,
+        byte_io: Literal[True],
+        buffering: Literal[0] = ...,
+    ) -> io.FileIO: ...
+
     @overload
     def open(
         self,
         *,
         byte_io: Literal[True],
         buffering: int = -1,
-    ) -> BinaryIO: ...
+    ) -> io.BufferedReader: ...
 
     def open(self, *, byte_io=False, buffering=-1):
         """Open the file for reading.  Usually used with a context manager
@@ -1926,7 +1934,7 @@ def documented_attr(
 
 
 def reference_documentation(
-    title: str = "Auto-generated reference documentation for ${RULE_NAME}",
+    title: str | None = None,
     description: str | None = textwrap.dedent(
         """\
             This is an automatically generated reference documentation for ${RULE_NAME}. It is generated
@@ -1970,6 +1978,8 @@ def reference_documentation(
     :param reference_documentation_url: A URL to the reference documentation.
     :return: An opaque representation of the documentation,
     """
+    if title is None:
+        title = "Auto-generated reference documentation for ${RULE_NAME}"
     return ParserDocumentation(
         synopsis,
         title,
