@@ -15,8 +15,7 @@ from debian.deb822 import Deb822
 from debian.debian_support import DpkgArchTable
 from debian.substvars import Substvars
 
-from debputy import DEBPUTY_PLUGIN_ROOT_DIR
-from debputy.architecture_support import faked_arch_table
+from debputy.architecture_support import DpkgArchitectureBuildProcessValuesTable
 from debputy.filesystem_scan import OSFSROOverlay, FSRootDir
 from debputy.packages import BinaryPackage, SourcePackage
 from debputy.plugin.api import (
@@ -64,6 +63,7 @@ from debputy.plugin.api.test_api.test_spec import (
 from debputy.plugins.debputy.debputy_plugin import initialize_debputy_features
 from debputy.substitution import SubstitutionImpl, VariableContext, Substitution
 from debputy.util import package_cross_check_precheck
+from debputy.version import DEBPUTY_PLUGIN_ROOT_DIR
 
 if TYPE_CHECKING:
     from debputy.highlevel_manifest import HighLevelManifest
@@ -293,7 +293,7 @@ def package_metadata_context(
     source_package_fields: dict[str, str] | None = None,
     manifest_configuration: ManifestConfigurationImplementation = lambda x, y: None,
 ) -> PackageProcessingContext:
-    process_table = faked_arch_table(host_arch)
+    process_table = DpkgArchitectureBuildProcessValuesTable(fake_host=host_arch)
     f = {
         "Package": "foo",
         "Architecture": "any",
