@@ -325,7 +325,7 @@ class ServiceRule:
             data.get("enable_on_install"),
             data.get("start_on_install"),
             data.get("on_upgrade"),
-            frozenset(service_managers) if service_managers else service_managers,
+            None if service_managers is None else frozenset(service_managers),
         )
 
     def applies_to_service_manager(self, service_manager: str) -> bool:
