@@ -1,17 +1,13 @@
-import dataclasses
 import itertools
 import os
 import re
 import subprocess
 import textwrap
+import typing
 from collections.abc import Iterable, Iterator, Mapping
 
-from debian.deb822 import PkgRelation
-
 from debputy.bug1120283 import holds_with_profiles, holds_on_arch
-from debputy.manifest_conditions import ManifestCondition
 from debputy.manifest_parser.util import AttributePath
-from debputy.packages import BinaryPackage
 from debputy.packaging.alternatives import SYSTEM_DEFAULT_PATH_DIRS
 from debputy.plugin.api import (
     VirtualPath,
@@ -28,7 +24,6 @@ from debputy.plugins.debputy.types import (
     DebputyCapability,
     BuiltUsing,
     StaticBuiltUsing,
-    BuiltUsingBase,
 )
 from debputy.util import assume_not_none, _debug_log, _error, _warn
 
@@ -581,41 +576,39 @@ def auto_depends_arch_any_solink(
         ctrl.substvars.add_dependency("misc:Depends", relation)
 
 
-def _built_using_enabled_match(
+def _built_using_enabled_matches(
     context: PackageProcessingContext,
-    pkg: BinaryPackage,
-    attribute_path: AttributePath,
-    manifest_condition: ManifestCondition,
-    relation: "PkgRelation.ParsedRelation",
-) -> bool:
-    # A logical conjunction of restrictions, with logging.
-    name = relation["name"]
+) -> Iterator["_BuiltUsingTodo"]:
+    """Helper implementing pass 1 of detect_built_using."""
+    pkg = context.binary_package
     host = pkg.resolved_architecture
     table = context.dpkg_arch_query_table
-    if not holds_on_arch(relation, host, table):
-        field = attribute_path["sources"]
-        _debug_log(f"{field}: {name} is disabled by host architecture {host}.")
-        return False
     profiles = context.deb_options_and_profiles.deb_build_profiles
-    if not holds_with_profiles(relation, profiles):
-        field = attribute_path["sources"]
-        _debug_log(f"{field}: {name} is disabled by profiles {' '.join(profiles)}.")
-        return False
-    if manifest_condition and not manifest_condition.evaluate(
-        context.condition_context(pkg)
+    condition_context = context.condition_context(pkg)
+    for cls, field in (
+        (BuiltUsing, "Built-Using"),
+        (StaticBuiltUsing, "Static-Built-Using"),
     ):
-        field = attribute_path["sources"]
-        _debug_log(f"{field}: {name} is disabled by its manifest condition.")
-        return False
-    return True
+        for deps, cond, attr in context.manifest_configuration(pkg, cls) or ():
+            for is_first, relation in deps:
+                name = relation["name"]
+                if not holds_on_arch(relation, host, table):
+                    _debug_log(
+                        f"{attr}: {name} in Build-Depends is disabled by host architecture {host}."
+                    )
+                elif not holds_with_profiles(relation, profiles):
+                    _debug_log(
+                        f"{attr}: {name} in Build-Depends is disabled by profiles {' '.join(profiles)}."
+                    )
+                elif cond is not None and not cond.evaluate(condition_context):
+                    _debug_log(f"{attr}: {name} is disabled by its manifest condition.")
+                else:
+                    yield _BuiltUsingTodo(field, name, is_first, attr)
 
 
-@dataclasses.dataclass(slots=True)
-class _BuiltUsingTodo:
-    """For efficiency, a first pass constructs a todo list, then at
-    most one dpkg-query subprocess is spawn."""
+class _BuiltUsingTodo(typing.NamedTuple):
+    """Data transmitted between the two passes of detect_built_using."""
 
-    pkg: BinaryPackage
     field: str
     dep: str
     first_option: bool  # This relation was the first in its alternative.
@@ -667,66 +660,41 @@ def _sources_for(
 
 
 def detect_built_using(
-    _fs_foot: VirtualPath,
+    _fs_root: VirtualPath,
     ctrl: BinaryCtrlAccessor,
     context: PackageProcessingContext,
 ) -> None:
-    binary_package = context.binary_package
-    built_using_conf = context.manifest_configuration(binary_package, list[BuiltUsing])
-    static_built_using_conf = context.manifest_configuration(
-        binary_package, list[StaticBuiltUsing]
-    )
+    """For efficiency on patterns like librust-*-dev, a first pass
+    constructs a todo list, then at most one dpkg-query subprocess is
+    spawn per binary package and the process actually happens.
+    """
 
-    all_built_using_conf: list[BuiltUsingBase] = []
+    all_todos = tuple(_built_using_enabled_matches(context))
+    if all_todos:
+        _built_using_process_matches(ctrl, all_todos)
 
-    if built_using_conf:
-        all_built_using_conf.extend(built_using_conf)
-    if static_built_using_conf:
-        all_built_using_conf.extend(static_built_using_conf)
 
-    all_todos = []
-
-    for conf in all_built_using_conf:
-        for matched_package in conf.matched_packages:
-
-            if _built_using_enabled_match(
-                context,
-                binary_package,
-                conf.attribute_path,
-                conf.conditional,
-                matched_package.relationship,
-            ):
-                all_todos.append(
-                    _BuiltUsingTodo(
-                        binary_package,
-                        conf.field_name(),
-                        matched_package.name,
-                        matched_package.is_first,
-                        conf.attribute_path,
-                    )
-                )
-
-    if not all_todos:
-        return
-
-    relevant_sources = _sources_for(sorted({t.dep for t in all_todos}))
+def _built_using_process_matches(
+    ctrl: BinaryCtrlAccessor,
+    all_todos: Iterable[_BuiltUsingTodo],
+) -> None:
+    """Helper implementing pass 2 of detect_built_using."""
+    relevant_sources = _sources_for(sorted(t.dep for t in all_todos))
     already_warned = set()
-    for t in all_todos:
-        if t.dep in relevant_sources:
+    for field, dep, first_option, attribute_path in all_todos:
+        if dep in relevant_sources:
             ctrl.substvars.add_dependency(
-                f"debputy:{t.field}",
-                relevant_sources[t.dep],
+                f"debputy:{field}",
+                relevant_sources[dep],
             )
-            continue
         # With `Build-Depends: a | b`, in usual configurations,
         # `a` is installed but `b` might not be.
-        field = t.attribute_path["sources"]
-        if t.first_option and t.dep not in already_warned:
+        elif first_option and dep not in already_warned:
             _warn(
-                f"{field}: {t.dep} is not installed despite being the first or only option in a Build-Depends clause. It will be omitted from the built-using fields."
+                f"{attribute_path.path}: {dep} is not installed despite being the first or only option in a Build-Depends clause. It will be omitted from the built-using fields."
             )
-            already_warned.add(t.dep)
+            already_warned.add(dep)
         else:
             _debug_log(
-                f"{field}: {t.dep} is not installed and therefore not included in the built-using fields."
+                f"{attribute_path.path}: {dep} is not installed and therefore not included in the built-using fields."
             )
