@@ -2,7 +2,7 @@ import collections
 import dataclasses
 import os
 import textwrap
-from typing import Dict, List, Literal
+from typing import Literal
 from collections.abc import Iterable, Sequence
 
 from debputy.packages import BinaryPackage
