@@ -15,7 +15,7 @@ from typing import (
     Self,
     is_typeddict,
 )
-from collections.abc import Sequence, Callable, Container, Iterable
+from collections.abc import Sequence, Callable, Container, Iterable, Iterator
 
 from debputy.exceptions import PluginAPIViolationError, PluginInitializationError
 from debputy.manifest_conditions import ManifestCondition, ConditionContext
@@ -191,11 +191,12 @@ class BuildRule(DebputyDispatchableType):
         for_packages = attributes.get("for_packages")
 
         if for_packages is None:
+            all_packages: Iterable[BinaryPackage]
             if isinstance(parser_context, ParserContextData):
-                all_binaries = parser_context.binary_packages.values()
+                all_packages = parser_context.binary_packages.values()
             else:
-                all_binaries = parser_context.all_packages
-            self._for_packages = frozenset(all_binaries)
+                all_packages = parser_context.all_packages
+            self._for_packages = frozenset(all_packages)
         else:
             selectors = (
                 for_packages if isinstance(for_packages, list) else [for_packages]
@@ -326,13 +327,12 @@ class BuildSystemRule(BuildRule):
         parser_context: Union[ParserContextData, "HighLevelManifest"],
     ) -> None:
         super().__init__(attributes, attribute_path, parser_context)
-        build_directory = _is_type_or_none(
-            attributes.get("build_directory"), FileSystemExactMatchRule
+        build_directory = attributes.get("build_directory")
+        self._build_directory = (
+            build_directory.match_rule.path
+            if isinstance(build_directory, FileSystemExactMatchRule)
+            else None
         )
-        if build_directory is not None:
-            self._build_directory = build_directory.match_rule.path
-        else:
-            self._build_directory = None
         self.source_directory = "."
         self.install_directly_to_package = False
         self.perform_in_source_build = _is_type_or_none(
@@ -398,7 +398,7 @@ class BuildSystemRule(BuildRule):
         return directory
 
     @contextlib.contextmanager
-    def dump_logs_on_error(self, *logs: str) -> None:
+    def dump_logs_on_error(self, *logs: str) -> Iterator[None]:
         """Context manager that will dump logs to stdout on error
 
         :param logs: The logs to be dumped. Relative path names are assumed to be relative to
@@ -760,7 +760,9 @@ class StepBasedBuildSystemRule(BuildSystemRule):
 
 
 # Using the same logic as debhelper for the same reasons.
-def _make_target_exists(make_cmd: str, target: str, *, directory: str = ".") -> bool:
+def _make_target_exists(
+    make_cmd: str, target: str, *, directory: str | None = None
+) -> bool:
     cmd = [
         make_cmd,
         "-s",
@@ -1077,6 +1079,8 @@ def debputy_build_system(
 
     if isinstance(auto_detection_shadows_build_systems, str):
         shadows = frozenset([auto_detection_shadows_build_systems])
+    elif auto_detection_shadows_build_systems is None:
+        shadows = frozenset()
     else:
         shadows = frozenset(auto_detection_shadows_build_systems)
 
