@@ -1,5 +1,6 @@
 import argparse
 import collections
+import enum
 import functools
 import glob
 import logging
@@ -11,27 +12,14 @@ import sys
 import time
 from itertools import zip_longest
 from pathlib import Path
-from typing import (
-    NoReturn,
-    TYPE_CHECKING,
-    Union,
-    Set,
-    FrozenSet,
-    Optional,
-    TypeVar,
-    Dict,
-    Literal,
-    Tuple,
-    List,
-    Any,
-)
+from typing import NoReturn, TYPE_CHECKING, Optional, TypeVar, Literal, Any
 from collections.abc import Iterator, Iterable, Sequence, Mapping
 
 from debian.deb822 import Deb822
 
-from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy.architecture_support import DpkgArchitectureBuildProcessValuesTable
 from debputy.exceptions import DebputySubstitutionError
+from debputy.version import debputy_doc_root_dir
 
 try:
     from Levenshtein import distance
@@ -88,9 +76,35 @@ PKGVERSION_REGEX = re.compile(
 """,
     re.VERBOSE | re.ASCII,
 )
-DEFAULT_PACKAGE_TYPE = "deb"
-DBGSYM_PACKAGE_TYPE = "deb"
-UDEB_PACKAGE_TYPE = "udeb"
+
+
+class PackageTypeSelector(enum.Flag):
+    DEB = enum.auto()
+    UDEB = enum.auto()
+    Singleton = Literal[DEB, UDEB]
+    ALL = DEB | UDEB
+
+    def __str__(self) -> str:
+        # 0 or ALL have no name, but only singletons are enumerated.
+        l = []
+        for p in self:
+            name = p.name
+            assert name is not None, repr(p)
+            l.append(name.lower())
+        return ", ".join(l)
+
+    @staticmethod
+    def singleton(s: str) -> Singleton:
+        """Like PackageTypeSelector[s.lower()], but typed as a
+        singleton and rejecting 'DeB' and 'ALL'."""
+        match s:
+            case "deb":
+                return PackageTypeSelector.DEB
+            case "udeb":
+                return PackageTypeSelector.UDEB
+            case _:
+                raise KeyError(s)
+
 
 POSTINST_DEFAULT_CONDITION = (
     '[ "$1" = "configure" ]'
@@ -274,7 +288,7 @@ def _normalize_link_target(link_target: str) -> str:
 
 
 def manifest_format_doc(anchor: str) -> str:
-    manifest_format = f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md"
+    manifest_format = f"{debputy_doc_root_dir()}/MANIFEST-FORMAT.md"
     return f"{manifest_format}#{anchor}" if anchor else manifest_format
 
 
