@@ -4,6 +4,7 @@ from debputy.plugin.api import (
     BinaryCtrlAccessor,
     PackageProcessingContext,
 )
+from debputy.util import PackageTypeSelector
 
 
 def _udeb_metadata_detector(
@@ -21,5 +22,7 @@ def custom_plugin_initializer(api: DebputyPluginInitializer) -> None:
         post_formatting_rewrite=lambda x: x.replace("+", "_"),
     )
     api.metadata_or_maintscript_detector(
-        "udeb-only", _udeb_metadata_detector, package_type="udeb"
+        "udeb-only",
+        _udeb_metadata_detector,
+        package_types=PackageTypeSelector.UDEB,
     )
