@@ -2004,7 +2004,7 @@ def test_migrate_dh_builtusing(
     )
     msg = (
         "Migrate all `${dh-builtusing:custom-pattern}` instances in the (Static-)Built-Using of libfoo1"
-        " to `packages.libfoo1.(static-)built-using.sources: glob-pattern` in `debian/debputy.manifest`"
+        " to `packages.libfoo1.(static-)built-using.sources-for: glob-pattern` in `debian/debputy.manifest`"
     )
     assert not migration.rename_paths_on_success
     assert not migration.remove_paths_on_success
