@@ -1,6 +1,6 @@
 import pytest
 
-from debputy.architecture_support import faked_arch_table
+from debputy.architecture_support import DpkgArchitectureBuildProcessValuesTable
 from debputy.commands.debputy_cmd.output import no_fancy_output
 from debputy.dh_migration.models import (
     DHMigrationSubstitution,
@@ -15,7 +15,10 @@ MOCK_ENV = {
     # This conflicts with the dpkg arch table intentionally (to ensure we can tell which one is being resolved)
     "DEB_HOST_ARCHITECTURE": "i386",
 }
-MOCK_DPKG_ARCH_TABLE = faked_arch_table("amd64", build_arch="i386")
+MOCK_DPKG_ARCH_TABLE = DpkgArchitectureBuildProcessValuesTable(
+    fake_host="amd64",
+    fake_build="i386",
+)
 MOCK_VARIABLE_CONTEXT = VariableContext(
     OSFSROOverlay.create_root_dir("debian", "debian")
 )
